************
Fix an Issue
************

The typical workflow for fixing a specific issue will look something like the following:


#. Identify `an issue <https://github.com/orgs/LSSTDESC/projects/6>`_ to work on. If you would like to contribute but don't have a specific issue, look at the `list of good first issues <https://github.com/orgs/LSSTDESC/projects/6/views/20>`_.

#. Assign the issue to yourself.

#. Leave a comment on the issue to let others know you're working on it.

Following the :ref:`Contribution workflow` guide, make a branch with a name like 
``issue/[#]/brief-description`` and make changes in your branch.
While developing in a branch, don't forget to pull from ``main`` regularly to
make sure your work is compatible with other recent changes.

When your code is complete, continue following the :ref:`Contribution workflow`,
and create a pull request.

If you find that you no longer have time to complete an issue, please unassign yourself
and leave a note in the comments describing what work has been done.
